<?php
/**
 * Initialize the options before anything else.
 */
add_action( 'init', 'custom_theme_options', 1 );

/**
 * Build the custom settings & update OptionTree.
 */
if (!function_exists('custom_theme_options')) {
    function custom_theme_options($return = false) {
        if(!  etheme_is_activated() ) return;

        /**
       * Get a copy of the saved settings array.
       */
      $saved_settings = get_option( 'option_tree_settings', array() );


      /**
       * Custom settings array that will eventually be
       * passes to the OptionTree Settings API Class.
       */

       $sections = array(
            array(
                'id'       => 'general',
                'title'    => __('General', 'legenda'),
                'icon'     => 'icon-cog'
            ),
            array(
                'id'       => 'color_scheme',
                'title'    => __('Color Scheme', 'legenda'),
                'icon'     => 'icon-picture'
            ),
            array(
                'id'       => 'typography',
                'title'    => __('Typography', 'legenda'),
                'icon'     => 'icon-text-height'
            ),
            array(
                'id'       => 'header',
                'title'    => __('Header', 'legenda'),
                'icon'     => 'icon-cogs'
            ),
            array(
                'id'       => 'footer',
                'title'    => __('Footer', 'legenda'),
                'icon'     => 'icon-cogs'
            ),
            array(
                'id'       => 'shop',
                'title'    => __('Shop', 'legenda'),
                'icon'     => 'icon-shopping-cart'
            ),
            array(
                'id'       => 'product_grid',
                'title'    => __('Products Page Layout', 'legenda'),
                'icon'     => 'icon-th'
            ),
            array(
                'id'       => 'single_product',
                'title'    => __('Single Product Page', 'legenda'),
                'icon'     => 'icon-file-alt'
            ),
            array(
                'id'       => 'quick_view',
                'title'    => __('Quick View', 'legenda'),
                'icon'     => 'icon-rocket'
            ),
            array(
                'id'       => 'search',
                'title'    => __('AJAX Search', 'legenda'),
                'icon'     => 'icon-search'
            ),
            array(
                'id'       => 'promo_popup',
                'title'    => __('Promo Popup', 'legenda'),
                'icon'     => 'icon-gift'
            ),
            array(
                'id'       => 'blog_page',
                'title'    => __('Blog Layout', 'legenda'),
                'icon'     => 'icon-indent-right'
            ),
            array(
                'id'       => 'portfolio',
                'title'    => __('Portfolio', 'legenda'),
                'icon'     => 'icon-briefcase'
            ),
            array(
                'id'       => 'contact_form',
                'title'    => __('Contact Form', 'legenda'),
                'icon'     => 'icon-envelope'
            ),
            array(
                'id'       => 'responsive',
                'title'    => __('Responsive', 'legenda'),
                'icon'     => 'icon-mobile-phone'
            ),
            array(
                'id'       => 'custom_css',
                'title'    => __('Custom CSS', 'legenda'),
                'icon'     => 'icon-paper-clip'
            ),
            array(
                'id'       => 'backup',
                'title'    => __('Import/Export', 'legenda'),
                'icon'     => 'icon-cog'
            )
       );

       $settings = array(
            array(
                'id'          => 'main_layout',
                'label'       => __('Site Layout', 'legenda'),
                'default'     => 'wide',
                'type'        => 'select',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 'wide',
                    'label' => __('Wide', 'legenda')
                  ),
                  array(
                    'value' => 'boxed',
                    'label' => __('Boxed' , 'legenda')
                  )
                )
            ),
            array(
                'id'          => 'to_top',
                'label'       => __('"Back To Top" button', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'fixed_nav',
                'label'       => __('Fixed navigation', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'nice_scroll',
                'label'       => __('Nice Scroll', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            /*
            array(
                'id'          => 'fade_animation',
                'label'       => 'Enable fade animation for header and content',
                'default'     => array(
                    0 => 0
                ),
                'type'        => 'checkbox',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),*/
            array(
                'id'          => 'favicon_badge',
                'label'       => __('Show products in cart count on the favicon', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'mobile_loader',
                'label'       => __('Show loader on mobile', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'general',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'google_code',
                'label'       => __('Google Analytics Code', 'legenda'),
                'default'     => '',
                'type'        => 'textarea_simple',
                'section'     => 'general'
            ),
            array(
                'id'          => 'deactivator_button',
                'label'       => __('Deactivate theme', 'legenda'),
                'default'     => 'Deactivate',
                'type'        => 'button',
                'section'     => 'general',
                'choices'     => array (
                    'value' => 'Deactivate'
                )
            ),
            // COLOR SCHEME
            array(
                'id'          => 'main_color_scheme',
                'label'       => __('Main color scheme', 'legenda'),
                'default'     => 'light',
                'type'        => 'select',
                'section'     => 'color_scheme',
                'choices'     => array(
                  array(
                    'value' => 'light',
                    'label' => __('Light', 'legenda')
                  ),
                  array(
                    'value' => 'dark',
                    'label' => __('Dark', 'legenda')
                  )
                )
            ),
            array(
                'id'          => 'activecol',
                'label'       => __('Main Color', 'legenda'),
                'default'     => '#ed1c2e',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme',
            ),
            array(
                'id'          => 'pricecolor',
                'label'       => __('Price Color', 'legenda'),
                'default'     => '#EE3B3B',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme',
            ),
            /*
            array(
                'id'          => 'activehovercol',
                'label'       => 'Active button hover Color',
                'default'     => '#e83636',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme',
            ),
            array(
                'id'          => 'footer_bg',
                'label'       => 'Footer Background Color',
                'default'     => '#222222',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme',
            ),*/
            array(
                'id'          => 'background_img',
                'label'       => __('Site Background', 'legenda'),
                'desc'        => '',
                'default'     => '',
                'type'        => 'background',
                'section'     => 'color_scheme',
            ),
            array(
                'id'          => 'background_cover',
                'label'       => __('Background Image Expanding', 'legenda'),
                'default'     => '',
                'type'        => 'select',
                'section'     => 'color_scheme',
                'choices'     => array(
                  array(
                    'value' => 'enable',
                    'label' => 'enable'
                  ),
                  array(
                    'value' => 'disable',
                    'label' => 'disable'
                  )
                )
            ),
            array(
                'id'          => 'header_color_scheme',
                'label'       => __('Header color scheme (Only for transparent header type)', 'legenda'),
                'default'     => 'light',
                'type'        => 'select',
                'section'     => 'color_scheme',
                'choices'     => array(
                  array(
                    'value' => 'light',
                    'label' => __('Light', 'legenda')
                  ),
                  array(
                    'value' => 'dark',
                    'label' => __('Dark', 'legenda')
                  )
                )
            ),
            array(
                'id'          => 'fixed_header_color',
                'label'       => __('Fixed header color', 'legenda'),
                'default'     => 'dark',
                'type'        => 'select',
                'section'     => 'color_scheme',
                'choices'     => array(
                  array(
                    'value' => 'dark',
                    'label' => __('Dark', 'legenda')
                  ),
                  array(
                    'value' => 'light',
                    'label' => __('Light', 'legenda')
                  ),
                )
            ),
            array(
                'id'          => 'fixed_bg',
                'label'       => 'Fixed header background color',
                'default'     => '',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme'
            ),
            array(
                'id'          => 'breadcrumb_bg',
                'label'       => 'Breadcrumbs background',
                'default'     => '',
                'type'        => 'background',
                'section'     => 'color_scheme'
            ),
            array(
                'id'          => 'mobile_menu_bg',
                'label'       => 'Mobile menu background',
                'default'     => '#151515',
                'std'         => '#151515',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme'
            ),
            array(
                'id'          => 'mobile_menu_br',
                'label'       => 'Mobile menu borders',
                'default'     => '#222222',
                'std'         => '#222222',
                'type'        => 'colorpicker',
                'section'     => 'color_scheme'
            ),
            // TYPOGRAPHY
            array(
                'id'          => 'mainfont',
                'label'       => __('Main Font', 'legenda'),
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'sfont',
                'label'       => __('Body Font', 'legenda'),
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'header_menu_font',
                'label'       => __('Main Menu Font', 'legenda'),
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'mobile_menu_font',
                'label'       => __('Mobile menu font', 'legenda'),
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'mobile_menu_headings_font',
                'label'       => __('Mobile headings font', 'legenda'),
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'h1',
                'label'       => 'H1',
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'h2',
                'label'       => 'H2',
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'h3',
                'label'       => 'H3',
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'h4',
                'label'       => 'H4',
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'h5',
                'label'       => 'H5',
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            array(
                'id'          => 'h6',
                'label'       => 'H6',
                'default'     => '',
                'type'        => 'typography',
                'section'     => 'typography',
            ),
            // HEADER
            array(
                'id'          => 'top_bar',
                'label'       => __('Enable top bar', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'top_panel',
                'label'       => __('Enable hidden top panel', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'header_type',
                'label'       => __('Header Type', 'legenda'),
                'default'     => 1,
                'type'        => 'radio-image',
                'section'     => 'header',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => 'Default',
                        'src'     => OT_URL . '/assets/images/header_v1.jpg'
                    ),
                    array(
                        'value'   => 2,
                        'label'   => 'Variant 2',
                        'src'     => OT_URL . '/assets/images/header_v2.jpg'
                    ),
                    array(
                        'value'   => 3,
                        'label'   => 'Variant 3',
                        'src'     => OT_URL . '/assets/images/header_v3.jpg'
                    ),
                    array(
                        'value'   => 4,
                        'label'   => 'Variant 4',
                        'src'     => OT_URL . '/assets/images/header_v4.jpg'
                    ),
                    array(
                        'value'   => 5,
                        'label'   => 'Variant 5',
                        'src'     => OT_URL . '/assets/images/header_v5.jpg'
                    ),
                    array(
                        'value'   => 6,
                        'label'   => 'Variant 6',
                        'src'     => OT_URL . '/assets/images/header_v6.jpg'
                    ),
                    array(
                        'value'   => 7,
                        'label'   => 'Default',
                        'src'     => OT_URL . '/assets/images/header_v7.jpg'
                    ),
                    array(
                        'value'   => 9,
                        'label'   => 'transparent',
                        'src'     => OT_URL . '/assets/images/header_v9.jpg'
                    ),
                    array(
                        'value'   => 8,
                        'label'   => 'Vertical',
                        'src'     => OT_URL . '/assets/images/header_v8.jpg'
                    ),
                )
            ),
    		/*
            array(
                'id'          => 'menu_type',
                'label'       => 'Menu Type',
                'default'     => '2',
                'type'        => 'select',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => '1',
                    'label' => 'Default Menu'
                  ),
                  array(
                    'value' => '2',
                    'label' => 'Mega Menu'
                  ),
                  array(
                    'value' => '3',
                    'label' => 'Drop Down Menu'
                  ),
                  array(
                    'value' => '4',
                    'label' => 'Combined'
                  )
                )
            ),*/
            array(
                'id'          => 'languages_area',
                'label'       => __('Enable languages area', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'right_panel',
                'label'       => __('Use right side panel', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'logo',
                'label'       => __('Logo image', 'legenda'),
                'default'     => '',
                'desc'        => 'Upload image: png, jpg or gif file',
                'type'        => 'upload',
                'section'     => 'header'
            ),
            array(
                'id'          => 'logo-fixed',
                'label'       => __('Logo image for fixed header', 'legenda'),
                'default'     => '',
                'desc'        => 'Upload image: png, jpg or gif file',
                'type'        => 'upload',
                'section'     => 'header'
            ),
            array(
                'id'          => 'favicon',
                'label'       => __('Favicon', 'legenda'),
                'default'     => '[template_url]/images/favicon.ico',
                'desc'        => __('Upload image: png, jpg or gif file','legenda'),
                'type'        => 'upload',
                'section'     => 'header'
            ),
            array(
                'id'          => 'top_links',
                'label'       => __('Enable top links (Register | Sign In)', 'legenda'),
                'default'     => array(
                	0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'cart_widget',
                'label'       => __('Enable cart widget', 'legenda'),
                'default'     => array(
                	0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'search_form',
                'label'       => __('Enable search form in header', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'wishlist_link',
                'label'       => __('Show wishlist link', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'header',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'breadcrumb_type',
                'label'       => __('Breadcrumb Type', 'legenda'),
                'default'     => 'default',
                'type'        => 'select',
                'section'     => 'header',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => '',
                        'label'   => __('Default', 'legenda')
                    ),
                    array(
                        'value'   => 'variant2',
                        'label'   => __('Wide block', 'legenda')
                    ),
                    array(
                        'value'   => 'without-title',
                        'label'   => __('Without title', 'legenda')
                    )
                )
            ),
            // FOOTER
            array(
                'id'          => 'footer_type',
                'label'       => __('Footer Type', 'legenda'),
                'default'     => 1,
                'type'        => 'radio-image',
                'section'     => 'footer',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => 'Default',
                        'src'     => OT_URL . '/assets/images/footer_v1.jpg'
                    ),
                    array(
                        'value'   => 2,
                        'label'   => 'Variant 2',
                        'src'     => OT_URL . '/assets/images/footer_v2.jpg'
                    ),
                    array(
                        'value'   => 3,
                        'label'   => 'Variant 3',
                        'src'     => OT_URL . '/assets/images/footer_v3.jpg'
                    )
                )
            ),
            array(
                'id'          => 'footer_demo',
                'label'       => __('Show footer demo blocks','legenda'),
                'desc'        => __('Will be shown if footer sidebars are empty', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'footer',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            // CONTACT FORM
            array(
                'id'          => 'google_map_enable',
                'label'       => __('Enable Google Map', 'legenda'),
                'default'     => array(0=>1),
                'type'        => 'checkbox',
                'section'     => 'contact_form',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'contact_page_type',
                'label'       => __('Choose contact page layout', 'legenda'),
                'default'     => 'default',
                'type'        => 'select',
                'section'     => 'contact_form',
                'choices'     => array(
                  array(
                    'value' => 'default',
                    'label' => __('Default Layout' , 'legenda')
                  ),
                  array(
                    'value' => 'custom',
                    'label' => __('Custom layout' , 'legenda')
                  )
                )
            ),
            array(
                'id'          => 'contacts_email',
                'label'       => __('Your email for contact form', 'legenda'),
                'default'     => 'test@gmail.com',
                'type'        => 'text',
                'section'     => 'contact_form'
            ),
            array(
                'id'          => 'google_map',
                'label'       => __('Longitude and Latitude for google map', 'legenda'),
                'desc'        => '<b>Example:</b>  51.507622,-0.1305',
                'default'     => '51.507622,-0.1305',
                'type'        => 'text',
                'section'     => 'contact_form'
            ),
            array(
                'id'          => 'google_map_api',
                'label'       => __('Google Map API', 'legenda'),
                'desc'        => '<b>To find your Google Map API visit <a href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank">documentation</a></b>',
                'default'     => '124537876',
                'type'        => 'text',
                'section'     => 'contact_form'
            ),
            // SHOP
            array(
                'id'          => 'just_catalog',
                'label'       => __('Just Catalog', 'legenda'),
                'desc'        => __('Disable "Add To Cart" button and shopping cart', 'legenda'),
                'default'     => 0,
                'type'        => 'checkbox',
                'section'     => 'shop',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'checkout_page',
                'label'       => __('Checkout page', 'legenda'),
                'type'        => 'select',
                'section'     => 'shop',
                'default'     => 'stepbystep',
                'choices'     => array(
                  array(
                    'value' => 'stepbystep',
                    'label' => __('Step By Step' , 'legenda')
                  ),
                  array(
                    'value' => 'default',
                    'label' => __('Default', 'legenda')
                  ),
                  array(
                    'value' => 'quick',
                    'label' => __('Quick Checkout', 'legenda')
                  )
                )
            ),
            array(
                'id'          => 'ajax_filter',
                'label'       => __('Enable Ajax Filter', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'shop',
                'default'     => array(
                    0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'cats_accordion',
                'label'       => __('Enable Navigation Accordion', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'shop',
                'default'     => array(
                	0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),/*
            array(
                'id'          => 'default_slider_height',
                'label'       => 'Product Sliders Height',
                'desc'        => '<b>Default: </b> 480',
                'type'        => 'text',
                'section'     => 'shop',
                'default'     => 480
            ),*/
            array(
                'id'          => 'out_of_label',
                'label'       => __('Enable "Out Of Stock" label', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'shop',
                'default'     => array(
                	0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'new_icon',
                'label'       => __('Enable "NEW" icon', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'shop',
                'default'     => array(
                	0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'new_icon_width',
                'label'       => __('"NEW" Icon width', 'legenda'),
                'desc'        => __('<b>Example: </b> 60', 'legenda'),
                'type'        => 'text',
                'section'     => 'shop',
                'default'     => 48
            ),
            array(
                'id'          => 'new_icon_height',
                'label'       => __('"NEW" Icon height', 'legenda'),
                'desc'        => __('<b>Example: </b> 20', 'legenda'),
                'type'        => 'text',
                'section'     => 'shop',
                'default'     => 48
            ),
            array(
                'id'          => 'new_icon_url',
                'label'       => __('"NEW" Icon Image', 'legenda'),
                'default'     => '',
                'desc'        => __('Upload image: png, jpg or gif file', 'legenda'),
                'type'        => 'upload',
                'section'     => 'shop'
            ),
            array(
                'id'          => 'sale_icon',
                'label'       => __('Enable "Sale" icon', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'shop',
                'default'     => array(
                	0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'sale_icon_width',
                'label'       => __('"SALE" Icon width', 'legenda'),
                'default'     => '',
                'desc'        => __('<b>Example: </b> 60', 'legenda'),
                'type'        => 'text',
                'section'     => 'shop',
                'default'     => 48
            ),
            array(
                'id'          => 'sale_icon_height',
                'label'       => __('"SALE" Icon height', 'legenda'),
                'default'     => '',
                'desc'        => __('<b>Example: </b> 20', 'legenda'),
                'type'        => 'text',
                'section'     => 'shop',
                'default'     => 48
            ),
            array(
                'id'          => 'sale_icon_url',
                'default'     => '',
                'label'       => __('"SALE" Icon Image', 'legenda'),
                'desc'        => __('Upload image: png, jpg or gif file', 'legenda'),
                'type'        => 'upload',
                'section'     => 'shop'
            ),
            array(
                'id'          => 'product_bage_banner',
                'label'       => __('Product Page Banner', 'legenda'),
                'default'     => '
    <p>
    <img src="[template_url]/images/assets/shop-banner.jpg" />
    </p>
                ',
                'desc'        => __('Upload image: png, jpg or gif file', 'legenda'),
                'type'        => 'textarea',
                'section'     => 'shop'
            ),
            array(
                'id'          => 'empty_cart_content',
                'label'       => __('Text for empty cart', 'legenda'),
                'default'     => __('
    <h2>Your cart is currently empty</h2>
    <p>You have not added any items in your shopping cart</p>
                ', 'legenda'),
                'type'        => 'textarea',
                'section'     => 'shop'
            ),
            array(
                'id'          => 'empty_category_content',
                'label'       => __('Text for empty category', 'legenda'),
                'default'     => __('
    <h2>No products were found</h2>
                ', 'legenda'),
                'type'        => 'textarea',
                'section'     => 'shop'
            ),

            // Product Grid

            array(
                'id'          => 'view_mode',
                'label'       => __('Products view mode', 'legenda'),
                'type'        => 'select',
                'section'     => 'product_grid',
                'default'     => 'grid_list',
                'class'       => 'prodcuts_per_row',
                'choices'     => array(
                  array(
                    'value' => 'grid_list',
                    'label' => __('Grid/List', 'legenda')
                  ),
                  array(
                    'value' => 'list_grid',
                    'label' => __('List/Grid', 'legenda')
                  ),
                  array(
                    'value' => 'grid',
                    'label' => __('Only Grid', 'legenda')
                  ),
                  array(
                    'value' => 'list',
                    'label' => __('Only List', 'legenda')
                  )
                )
            ),
            array(
                'id'          => 'prodcuts_per_row',
                'label'       => __('Products per row', 'legenda'),
                'type'        => 'select',
                'section'     => 'product_grid',
                'default'     => 3,
                'class'       => 'prodcuts_per_row',
                'choices'     => array(
                  array(
                    'value' => 3,
                    'label' => '3'
                  ),
                  array(
                    'value' => 4,
                    'label' => '4'
                  ),
                  array(
                    'value' => 5,
                    'label' => '5'
                  ),
                  array(
                    'value' => 6,
                    'label' => '6'
                  ),
                )
            ),
            array(
                'id'          => 'products_per_page',
                'label'       => __('Products per page', 'legenda'),
                'type'        => 'text',
                'default'     => 12,
                'section'     => 'product_grid'
            ),
            array(
                'id'          => 'grid_sidebar',
                'label'       => __('Layout', 'legenda'),
                // 'desc'        => __('Sidebar position', 'legenda'),
                'default'     => 'left',
                'type'        => 'radio-image',
                'section'     => 'product_grid',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'left',
                        'label'   => __('Left Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                    array(
                        'value'   => 'right',
                        'label'   => __('Right Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/right-sidebar.png'
                    ),
                    array(
                        'value'   => 'without',
                        'label'   => __('Without Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/full-width.png'
                    )
                )
            ),
            array(
                'id'          => 'sidebar_position_mobile',
                'label'       => __('Sidebar position on mobile', 'legenda'),
                'type'        => 'select',
                'section'     => 'product_grid',
                'default'     => 'under',
                'choices'     => array(
                  array(
                    'value' => 'above',
                    'label' => 'Above content'
                  ),
                  array(
                    'value' => 'under',
                    'label' => 'Under content'
                  ),
                )
            ),
            array(
                'id'          => 'category_description_position',
                'label'       => __('Category description position', 'legenda'),
                'type'        => 'select',
                'section'     => 'product_grid',
                'default'     => 'under',
                'choices'     => array(
                  array(
                    'value' => 'above',
                    'label' => 'Above products'
                  ),
                  array(
                    'value' => 'under',
                    'label' => 'Under products'
                  ),
                )
            ),
            array(
                'id'          => 'product_img_hover',
                'label'       => __('Product Image Hover', 'legenda'),
                'type'        => 'select',
                'section'     => 'product_grid',
                'default'     => 'slider',
                'choices'     => array(
                  array(
                    'value' => 'disable',
                    'label' => __('Disable', 'legenda')
                  ),
                  array(
                    'value' => 'description',
                    'label' => __('Description', 'legenda')
                  ),
                  array(
                    'value' => 'swap',
                    'label' => __('Swap', 'legenda')
                  ),
                  array(
                    'value' => 'tooltip',
                    'label' => __('Tooltip', 'legenda')
                  ),
                  array(
                    'value' => 'slider',
                    'label' => __('Images Slider' , 'legenda')
                  ),
                )
            ),
            array(
                'id'          => 'descr_length',
                'label'       => __('Number of words for description (hover effect)', 'legenda'),
                'default'     => 30,
                'type'        => 'text',
                'section'     => 'product_grid'
            ),
            array(
                'id'          => 'product_page_productname',
                'label'       => __('Show product name', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'product_grid',
                'default'     => array(
                    0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'product_page_cats',
                'label'       => __('Show product categories', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'product_grid',
                'default'     => array(
                    0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'product_page_price',
                'label'       => __('Show Price', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'product_grid',
                'default'     => array(
                	0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'product_page_addtocart',
                'label'       => __('Show "Add to cart" button', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'product_grid',
                'default'     => array(
                	0 => 1
                ),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            // BLOG
            array(
                'id'          => 'blog_layout',
                'label'       => __('Blog Layout', 'legenda'),
                'type'        => 'select',
                'section'     => 'blog_page',
                'default'     => 'default',
                'choices'     => array(
                  array(
                    'value' => 'default',
                    'label' => 'Default'
                  ),
                  array(
                    'value' => 'grid',
                    'label' => 'Grid'
                  ),
                  array(
                    'value' => 'timeline',
                    'label' => 'Timeline'
                  ),
                  array(
                    'value' => 'default_portrait',
                    'label' => 'Small'
                  ),
                )
            ),
            /*
            array(
                'id'          => 'default_blog_slider_height',
                'label'       => 'Posts Sliders Height',
                'desc'        => '<b>Default: </b> 300',
                'type'        => 'text',
                'section'     => 'blog_page',
                'default'     => 300
            ),*/
            array(
                'id'          => 'ajax_posts_loading',
                'label'       => __('AJAX Infinite Posts Loading', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'blog_page',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'blog_lightbox',
                'label'       => __('Enable Lightbox For Blog Posts', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'blog_page',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'blog_slider',
                'label'       => __('Enable Sliders for posts images', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'blog_page',
                'default'     => 1,
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'posts_links',
                'label'       => __('Show Previous and Next posts links', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'blog_page',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'post_title',
                'label'       => __('Show Post title', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'blog_page',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'post_share',
                'label'       => __('Show Share buttons', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'blog_page',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array (
              'id' => 'excerpt_length',
              'label' => __('Excerpt length (words)', 'legenda'),
              'type' => 'text',
              'section' => 'blog_page',
              'default' => '50'
            ),
            /*
            array(
                'id'          => 'blog_layout',
                'label'       => 'Blog page layout',
                'default'     => 'default',
                'type'        => 'radio-image',
                'section'     => 'blog_page',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'default',
                        'label'   => 'Default',
                        'src'     => get_template_directory_uri().'/code/css/images/blog_1.jpg'
                    ),
                    array(
                        'value'   => 'portrait',
                        'label'   => 'Portrait Images',
                        'src'     => get_template_directory_uri().'/code/css/images/blog_2.jpg'
                    ),
                    array(
                        'value'   => 'horizontal',
                        'label'   => 'Portrait Images 2',
                        'src'     => get_template_directory_uri().'/code/css/images/blog_3.jpg'
                    )
                )
            ),*/
            array(
                'id'          => 'blog_sidebar',
                'label'       => __('Sidebar position', 'legenda'),
                'default'     => 'left',
                'type'        => 'radio-image',
                'section'     => 'blog_page',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'no_sidebar',
                        'label'   => __('Without Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value'   => 'left',
                        'label'   => __('Left Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                    array(
                        'value'   => 'right',
                        'label'   => __('Right Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/right-sidebar.png'
                    )
                )
            ),
            array(
                'id'          => 'blog_sidebar_width',
                'label'       => __('Sidebar width', 'legenda'),
                'default'     => 4,
                'type'        => 'select',
                'section'     => 'blog_page',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 4,
                        'label'   => '1/3'
                    ),
                    array(
                        'value'   => 3,
                        'label'   => '1/4'
                    ),
                    array(
                        'value'   => 2,
                        'label'   => '1/6'
                    ),
                )
            ),
            array(
                'id'          => 'blog_sidebar_responsive',
                'label'       => __('Sidebar position for responsive layout', 'legenda'),
                'default'     => 'bottom',
                'type'        => 'select',
                'section'     => 'blog_page',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'top',
                        'label'   => __('Top', 'legenda')
                    ),
                    array(
                        'value'   => 'bottom',
                        'label'   => __('Bottom', 'legenda')
                    )
                )
            ),
            // Single Product Page
            array(
                'id'          => 'single_sidebar',
                'label'       => __('Sidebar position', 'legenda'),
                'default'     => 'right',
                'type'        => 'radio-image',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'no_sidebar',
                        'label'   => __('Without Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value'   => 'left',
                        'label'   => __('Left Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                    array(
                        'value'   => 'right',
                        'label'   => __('Right Sidebar', 'legenda'),
                        'src'     => OT_URL . '/assets/images/layout/right-sidebar.png'
                    )
                )
            ),
            array(
                'id'          => 'upsell_location',
                'label'       => __('Location of upsell products', 'legenda'),
                'default'     => 'sidebar',
                'type'        => 'select',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'sidebar',
                        'label'   => __('Sidebar', 'legenda')
                    ),
                    array(
                        'value'   => 'after_content',
                        'label'   => __('After content', 'legenda')
                    )
                )
            ),
            array(
                'id'          => 'show_related',
                'label'       => __('Show related products', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),
            array(
                'id'          => 'hide_out_of_stock',
                'label'       => __('Hide out of stock items from related products', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),
            array(
                'id'          => 'ajax_addtocart',
                'label'       => __('Ajax "Add To Cart" (for simple products only)', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),
            array(
                'id'          => 'show_name_on_single',
                'label'       => __('Show Product name', 'legenda'),
                'default'     => 0,
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),
            /*
            array(
                'id'          => 'product_qr_code',
                'label'       => 'Show QR Code with the product URL',
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),*/
            array(
                'id'          => 'zoom_effect',
                'label'       => __('Zoom effect', 'legenda'),
                'default'     => 'window',
                'type'        => 'select',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'disable',
                        'label'   => __('Disable', 'legenda')
                    ),
                    array(
                        'value'   => 'slippy',
                        'label'   => __('Slippy', 'legenda')
                    ),
                    array(
                        'value'   => 'window',
                        'label'   => __('Window', 'legenda')
                    )
                )
            ),
            array(
                'id'          => 'gallery_lightbox',
                'label'       => __('Enable Lightbox for Product Images', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),/*
            array(
                'id'          => 'size_guide_img',
                'label'       => 'Size Guide img',
                'default'     => 'wp-content/themes/theleader/images/assets/sizeguide.jpg',
                'desc'        => 'Upload image: png, jpg or gif file',
                'type'        => 'upload',
                'section'     => 'single_product'
            ),
            array(
                'id'          => 'size_guide_img_mobile',
                'label'       => 'Size Guide img (mobile)',
                'default'     => 'wp-content/themes/idstore/images/assets/size-guide-mobile.jpg',
                'desc'        => 'Upload image: png, jpg or gif file',
                'type'        => 'upload',
                'section'     => 'single_product'
            ),*/
            array(
                'id'          => 'tabs_type',
                'label'       => __('Tabs type', 'legenda'),
                'default'     => 'tabs_default',
                'type'        => 'select',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'tabs-default',
                        'label'   => __('Default', 'legenda')
                    ),
                    array(
                        'value'   => 'left-bar',
                        'label'   => __('Left Bar', 'legenda')
                    ),
                    array(
                        'value'   => 'right-bar',
                        'label'   => __('Right Bar', 'legenda')
                    ),
                    array(
                        'value'   => 'accordion',
                        'label'   => __('Accordion', 'legenda')
                    )
                )
            ),
            array(
                'id'          => 'tabs_position',
                'label'       => __('Tabs position', 'legenda'),
                'default'     => 'tabs_default',
                'type'        => 'select',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'tabs-under',
                        'label'   => __('Under Content', 'legenda')
                    ),
                    array(
                        'value'   => 'tabs-inside',
                        'label'   => __('Inside Content', 'legenda')
                    )
                )
            ),
            array(
                'id'          => 'share_icons',
                'label'       => __('Show share buttons', 'legenda'),
                'default'     => array(
                    0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'single_product',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => ''
                    )
                )
            ),
            array(
                'id'          => 'custom_tab_title',
                'label'       => __('Custom Tab Title', 'legenda'),
                'default'     => 'Returns & Delivery',
                'type'        => 'text',
                'section'     => 'single_product'
            ),
            array(
                'id'          => 'custom_tab',
                'label'       => __('Return', 'legenda'),
                'desc'        => __('Enter custom content you would like to output to the product custom tab (for all products)', 'legenda'),
                'default'     => '
    [row][column size="one-half"]<h5>Returns and Exchanges</h5><p>There are a few important things to keep in mind when returning a product you purchased.You can return unwanted items by post within 7 working days of receipt of your goods.</p>[checklist style="arrow"]
    <ul>
    <li>You have 14 calendar days to return an item from the date you received it. </li>
    <li>Only items that have been purchased directly from Us.</li>
    <li>Please ensure that the item you are returning is repackaged with all elements.</li>
    </ul>
    [/checklist] [/column][column size="one-half"]
    <h5>Ship your item back to Us</h5>Firstly Print and return this Returns Form to:<br /> <p>30 South Park Avenue, San Francisco, CA 94108, USA<br /> Please remember to ensure that the item you are returning is repackaged with all elements.</p><br /> <span class="underline">For more information, view our full Returns and Exchanges information.</span>[/column][/row]
                ',
                'type'        => 'textarea',
                'section'     => 'single_product'
            ),
            array(
                'id'          => 'demo_data',
                'label'       => __('Base demo content', 'legenda'),
                'default'     => '',
                'desc'        => '',
                'type'        => 'demo_data',
                'section'     => 'backup',
                'choices'     => array(
                    array(
                        'value'   => 'e-commerce',
                        'label'   => __('E-commerce', 'legenda')
                    ),
                    array(
                        'value'   => 'corporate',
                        'label'   => __('Corporate', 'legenda')
                    ),
                )
            ),
            array(
                'id'          => 'import_export',
                'label'       => __('Import or Export your theme configuration', 'legenda'),
                'default'     => '',
                'desc'        => '',
                'type'        => 'backup',
                'section'     => 'backup'
            ),
            // QUICK VIEW
            array(
                'id'          => 'quick_view',
                'label'       => __('ENABLE QUICK VIEW', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_images',
                'label'       => __('Product images', 'legenda'),
                'default'     => 'slider',
                'type'        => 'select',
                'section'     => 'quick_view',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 'none',
                        'label'   => __('None', 'legenda')
                    ),
                    array(
                        'value'   => 'slider',
                        'label'   => __('Slider', 'legenda')
                    ),
                    array(
                        'value'   => 'single',
                        'label'   => __('Single', 'legenda')
                    )
                )
            ),
            array(
                'id'          => 'quick_product_name',
                'label'       => __('Product name', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_price',
                'label'       => __('Price', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_rating',
                'label'       => __('Product star rating', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_sku',
                'label'       => __('Product code', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_descr',
                'label'       => __('Short description', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_add_to_cart',
                'label'       => __('Add to cart', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'quick_share',
                'label'       => __('Share icons', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'quick_view',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            // Search
            array(
                'id'          => 'search_products',
                'label'       => __('Search by products', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'search',
                'default'     => 1,
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'search_out_products',
                'label'       => __('Show out of stock products in Ajax search form', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'search',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'search_posts',
                'label'       => __('Search by posts', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'search',
                'default'     => 1,
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'search_projects',
                'label'       => __('Search by projects', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'search',
                'default'     => 1,
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'search_pages',
                'label'       => __('Search by pages', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'search',
                'default'     => 1,
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'search_result_count',
                'label'       => __('Search result count', 'legenda'),
                'desc'        => __('<b>Example: </b> 5', 'legenda'),
                'type'        => 'text',
                'section'     => 'search',
                'default'     => 3
            ),
            array(
                'id'          => 'promo_popup',
                'label'       => __('Enable promo popup', 'legenda'),
                'default'     => 'sidebar',
                'type'        => 'select',
                'section'     => 'promo_popup',
                'class'       => '',
                'choices'     => array(
                    array(
                        'value'   => 1,
                        'label'   => __('Enabled', 'legenda')
                    ),
                    array(
                        'value'   => 0,
                        'label'   => __('Disabled', 'legenda')
                    ),
                    array(
                        'value'   => 'home',
                        'label'   => __('Enabled for home only', 'legenda')
                    )
                )
            ),
            array(
                'id'          => 'pp_content',
                'label'       => __('Popup content', 'legenda'),
                'type'        => 'textarea',
                'section'     => 'promo_popup',
                'default'     => 'You can add any HTML here (admin -> Theme Options -> Promo Popup).<br> We suggest you create a static block and put it here using shortcode'
            ),
            array(
                'id'          => 'pp_width',
                'label'       => __('Popup width', 'legenda'),
                'default'     => 750,
                'type'        => 'text',
                'section'     => 'promo_popup'
            ),
            array(
                'id'          => 'pp_height',
                'label'       => __('Popup height', 'legenda'),
                'default'     => 350,
                'type'        => 'text',
                'section'     => 'promo_popup'
            ),
            array(
                'id'          => 'pp_bg',
                'label'       => __('Popup background', 'legenda'),
                'default'     => '',
                'type'        => 'background',
                'section'     => 'promo_popup'
            ),
            // Portfolio
            array(
                'id'          => 'portfolio_count',
                'label'       => __('Items per page', 'legenda'),
                'default'     => -1,
                'desc'        => 'Use -1 to show all items',
                'type'        => 'text',
                'section'     => 'portfolio'
            ),
            array(
                'id'          => 'portfolio_columns',
                'label'       => __('Columns', 'legenda'),
                'type'        => 'select',
                'section'     => 'portfolio',
                'default'     => 3,
                'choices'     => array(
                  array(
                    'value' => 2,
                    'label' => 2
                  ),
                  array(
                    'value' => 3,
                    'label' => 3
                  ),
                  array(
                    'value' => 4,
                    'label' => 4
                  ),
                )
            ),
            array(
                'id'          => 'project_name',
                'label'       => __('Show Project names', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'portfolio',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'project_byline',
                'label'       => __('Show ByLine', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'portfolio',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'project_excerpt',
                'label'       => __('Show Excerpt', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'portfolio',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'recent_projects',
                'label'       => __('Show recent projects', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'portfolio',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'portfolio_comments',
                'label'       => __('Enable Comments For Projects', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'portfolio',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'portfolio_lightbox',
                'label'       => __('Enable Lightbox For Projects', 'legenda'),
                'type'        => 'checkbox',
                'section'     => 'portfolio',
                'default'     => array(0=>1),
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  ),
                )
            ),
            array(
                'id'          => 'portfolio_image_width',
                'label'       => __('Project Images Width', 'legenda'),
                'default'     => 720,
                'type'        => 'text',
                'section'     => 'portfolio'
            ),
            array(
                'id'          => 'portfolio_image_height',
                'label'       => __('Project Images Height', 'legenda'),
                'default'     => 550,
                'type'        => 'text',
                'section'     => 'portfolio'
            ),
            // Responsive
            array(
                'id'          => 'responsive',
                'label'       => __('Enable Responsive Design', 'legenda'),
                'default'     => array(
                	0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'responsive',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'responsive_from',
                'label'       => __('Large resolution from', 'legenda'),
                'desc'        => __('By default: 1200', 'legenda'),
                'default'     => 1200,
                'type'        => 'text',
                'section'     => 'responsive',
            ),
            /*
            array(
                'id'          => 'loader',
                'label'       => 'Show loader icon until site loading on mobile devices',
                'default'     => array(
                	0 => 1
                ),
                'type'        => 'checkbox',
                'section'     => 'responsive',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),
            array(
                'id'          => 'banner_mask',
                'label'       => 'Show banner mask on mobile device',
                'default'     => 'enable',
                'type'        => 'select',
                'section'     => 'responsive',
                'choices'     => array(
                  array(
                    'value' => 'enable',
                    'label' => 'Enable'
                  ),
                  array(
                    'value' => 'disable',
                    'label' => 'Disable'
                  ),
                )
            ),*/
            // Custom CSS
            array(
                'id'          => 'custom_css',
                'label'       => __('Enable Custom CSS file', 'legenda'),
                'desc'        => __('Enable this option to load "custom.css" file in which you can override the default styling of the theme. To create "custom.css" you can use the file "default.custom.css" which is located in theme directory.', 'legenda'),
                'default'     => 0,
                'type'        => 'checkbox',
                'section'     => 'custom_css',
                'choices'     => array(
                  array(
                    'value' => 1,
                    'label' => ''
                  )
                )
            ),



       );

       if($return) {
    	   return $settings;
       }

      $custom_settings = array(
        'contextual_help' => array(
          'content'       => array(
            array(
              'id'        => 'general_help',
              'title'     => __('General', 'legenda'),
              'content'   => ''
            )
          ),
          'sidebar'       => '',
        ),
        'sections'        => $sections,
        'settings'        => $settings
      );

      if(is_array($settings)){
    	  foreach($settings as $key => $value){
    		  $defaults[$value['id']] = $value['default'];
    	  }
      }

      add_option( 'option_tree', $defaults ); // update_option  add_option


      /* settings are not the same update the DB */
      if ( $saved_settings !== $custom_settings ) {
        update_option( 'option_tree_settings', $custom_settings );
      }

    }

    /**
     * Initialize the meta boxes for pages.
     */
    add_action( 'admin_init', 'page_meta_boxes' );


    function page_meta_boxes() {
    global $wpdb;
        $page_options = array(
            array(
                'id'          => 'sidebar_state',
                'label'       => __('Sidebar Position', 'legenda'),
                'type'        => 'select',
                'choices'     => array(
                      array(
                        'value' => '',
                        'label' => __('Default' , 'legenda')
                      ),
                      array(
                        'value' => 'no_sidebar',
                        'label' => __('Without Sidebar', 'legenda')
                      ),
                      array(
                        'value' => 'left',
                        'label' => __('Left Sidebar', 'legenda')
                      ),
                      array(
                        'value' => 'right',
                        'label' => __('Right Sidebar' , 'legenda')
                      )
                    )
            ),
            array(
                'id'          => 'widget_area',
                'label'       => __('Widget Area', 'legenda'),
                'type'        => 'sidebar_select'
            ),
            array(
                'id'          => 'sidebar_width',
                'label'       => __('Sidebar width', 'legenda'),
                'type'        => 'select',
                'choices'     => array(
                      array(
                        'value' => '',
                        'label' => 'Default'
                      ),
                      array(
                        'value' => 2,
                        'label' => '1/6'
                      ),
                      array(
                        'value' => 3,
                        'label' => '1/4'
                      ),
                      array(
                        'value' => 4,
                        'label' => '1/3'
                      )
                    )
            ),
            array(
                'id'          => 'page_heading',
                'label'       => __('Show Page Heading', 'legenda'),
                'type'        => 'select',
                'choices'     => array(
                      array(
                        'value' => 'enable',
                        'label' => 'Enable'
                      ),
                      array(
                        'value' => 'disable',
                        'label' => 'Disable'
                      )
                    )
            ),
            array(
                'id'          => 'custom_logo',
                'label'       => __('Custom logo for this page', 'legenda'),
                'type'        => 'upload'
            ),
            array(
                'id'          => 'custom_nav',
                'label'       => 'Custom navigation for this page',
                'type'        => 'select',
                'choices'     => et_get_menus_options()
            ),

        );

        if(class_exists('RevSliderAdmin')) {

        	$rs = $wpdb->get_results(
        		"
        		SELECT id, title, alias
        		FROM ".$wpdb->prefix."revslider_sliders
        		ORDER BY id ASC LIMIT 100
        		"
        	);
        	$revsliders = array(array(
        		'value' => 'no_slider',
        		'label' => 'No Slider'
        	));
        	if ($rs) {
        	$_ri = 1;
        	foreach ( $rs as $slider ) {
        	  	$revsliders[$_ri]['value'] = $slider->alias;
        	  	$revsliders[$_ri]['label'] = $slider->title;
        		$_ri++;
        	}
        	} else {
        		$revsliders["No sliders found"] = 0;
        	}


            if(count($revsliders)>0 ){
        	    array_push($page_options, array(
                    'id'          => 'page_slider',
                    'label'       => __('Show revolution slider instead of breadcrumbs and page title', 'legenda'),
                    'type'        => 'select',
                    'choices'     => $revsliders
                ));
            }
        }

      $my_meta_box = array(
        'id'        => 'page_layout',
        'title'     => __('Page Layout', 'legenda'),
        'desc'      => '',
        'pages'     => array( 'page', 'post' ),
        'context'   => 'side',//side normal
        'priority'  => 'low',
        'fields'    => $page_options
      );

      ot_register_meta_box( $my_meta_box );

    }


    /**
     * Initialize the meta boxes for products.
     */
    add_action( 'admin_init', 'products_meta_boxes' );


    function products_meta_boxes() {
    	$statick_blocks = array();
    	$statick_blocks[] = array("label"=>"--choose--","value"=>"");
    	$statick_blocks = array_merge($statick_blocks, et_get_static_blocks());

        $page_options = array(
            array(
                'id'          => 'additional_block',
                'label'       => __('Additional information block', 'legenda'),
                'type'        => 'select',
                'choices'     => $statick_blocks
            ),
            array(
                'id'          => 'product_new',
                'label'       => __('Mark product as "New"', 'legenda'),
                'type'        => 'select',
                'choices'     => array(
                  array(
                    'value' => 'disable',
                    'label' => 'Choose'
                  ),
                  array(
                    'value' => 'disable',
                    'label' => 'No'
                  ),
                  array(
                    'value' => 'enable',
                    'label' => 'Yes'
                  )
                )
            ),

            array(
                'id'          => 'size_guide_img',
                'label'       => __('Size Guide img', 'legenda'),
                'desc'        => __('Upload image: png, jpg or gif file', 'legenda'),
                'type'        => 'upload'
            ),
            array(
                'id'          => 'hover_img',
                'label'       => __('Upload image for hover effect', 'legenda'),
                'type'        => 'upload'
            ),
            array(
                'id'          => 'custom_tab1_title',
                'label'       =>  __('Title for custom tab', 'legenda'),
                'type'        => 'text'
            ),
            array(
                'id'          => 'custom_tab1',
                'label'       => __('Text for custom tab', 'legenda'),
                'type'        => 'textarea'
            ),
        );

      $my_meta_box = array(
        'id'        => 'product_options',
        'title'     => __('Additional product options [8theme]', 'legenda'),
        'desc'      => '',
        'pages'     => array( 'product' ),
        'context'   => 'normal',//side normal
        'priority'  => 'low',
        'fields'    => $page_options
      );

      ot_register_meta_box( $my_meta_box );

    }

    /**
     * Initialize the meta boxes for portfolio.
     */
    //add_action( 'admin_init', 'portfolio_meta_boxes' );


    function portfolio_meta_boxes() {
        $page_options = array(
            array(
                'id'          => 'project_url',
                'label'       => 'Project Url',
                'type'        => 'text'
            ),
            array(
                'id'          => 'client',
                'label'       => 'Client',
                'type'        => 'text'
            ),
            array(
                'id'          => 'client_url',
                'label'       => 'Client Url',
                'type'        => 'text'
            ),
            array(
                'id'          => 'copyright',
                'label'       => 'Copyright',
                'type'        => 'text'
            ),
            array(
                'id'          => 'copyright_url',
                'label'       => 'Copyright Url',
                'type'        => 'text'
            ),
        );

      $my_meta_box = array(
        'id'        => 'product_options',
        'title'     => __('Additional project information', 'legenda'),
        'desc'      => '',
        'pages'     => array( 'etheme_portfolio' ),
        'context'   => 'normal',//side normal
        'priority'  => 'low',
        'fields'    => $page_options
      );

      ot_register_meta_box( $my_meta_box );

    }


    if ( ! function_exists( 'ot_type_button' ) ) {
    function ot_type_button( $args = array() ) {
        extract( $args ); ?>
        <div class="format-setting">
           <?php if ($field_desc) : ?> <div class="description"><?php echo $field_desc; ?></div> <?php endif; ?>
            <button class="etheme-deactivator et-button"><?php echo $field_choices['value']; ?></button>
        </div>
    <?php } }

    function etheme_theme_settings_defaults() {
    	$defaults = array();
    	return apply_filters('etheme_theme_settings_defaults', $defaults);
    }
}
?>
